@@ -37,12 +37,15 @@ def reset(rio: ReadingIO) -> ReadingIO:
 
 
 def prefix_len(rio: ReadingIO) -> ReadingIO:
-    bts = rio.buff.read()
-    wio = WritingIO()
+    bts = rio.read_bytes()
+    wio = WritingIO(BytesIO())
     wio.write_int32(len(bts))
     wio.write_bytes(bts)
 
-    return ReadingIO(ReadingIO(wio.buff))
+    buff = wio.buff
+    buff.seek(0)
+
+    return ReadingIO(buff)
 
 
 def read_ssl_request(context: Context):
